@@ -1,6 +1,6 @@
 package Test::Mocha::Method;
 {
-  $Test::Mocha::Method::VERSION = '0.21_02';
+  $Test::Mocha::Method::VERSION = '0.49_01';
 }
 # ABSTRACT: Objects to represent methods and their arguuments
 
@@ -15,19 +15,12 @@ use Types::Standard    qw( ArrayRef HashRef Str );
 
 use overload '""' => \&stringify, fallback => 1;
 
-# croak() messages should not trace back to Mocha modules
-our @CARP_NOT = qw(
-    Test::Mocha::Inspect
-    Test::Mocha::Mock
-    Test::Mocha::Verify
-);
-
 # cause string overloaded objects (Matchers) to be stringified
 my $Dumper = Test::Mocha::PartialDump->new(objects => 0, stringify => 1);
 
 sub new {
     # uncoverable pod
-    my ($class, %args) = @_;
+    my ( $class, %args ) = @_;
     ### assert: Str->check( $args{name} )
     ### assert: ArrayRef->check( $args{args} )
     return bless \%args, $class;
@@ -49,13 +42,13 @@ sub stringify {
     # you'd type in Perl.
     # """
     # uncoverable pod
-    my ($self) = @_;
+    my ( $self ) = @_;
     return $self->name . '(' . $Dumper->dump($self->args) . ')';
 }
 
 my $slurp = sub {
     # """check slurpy arguments"""
-    my ($slurpy_matcher, @to_match) = @_;
+    my ( $slurpy_matcher, @to_match ) = @_;
 
     ### assert: Slurpy->check($slurpy_matcher)
     my $matcher = $slurpy_matcher->{slurpy};
@@ -80,7 +73,7 @@ sub satisfied_by {
     # Returns true if the given C<$invocation> satisfies this method call.
     # """
     # uncoverable pod
-    my ($self, $invocation) = @_;
+    my ( $self, $invocation ) = @_;
 
     return unless $invocation->name eq $self->name;
 
@@ -96,15 +89,15 @@ sub satisfied_by {
             croak 'No arguments allowed after a slurpy type constraint'
                 unless @expected == 0;
 
-            return unless $slurp->($matcher, @input);
+            return unless $slurp->( $matcher, @input );
 
             @input = ();
         }
         elsif ( Matcher->check($matcher) ) {
-            return unless $matcher->check(shift @input);
+            return unless $matcher->check( shift @input );
         }
         else {
-            return unless match(shift(@input), $matcher);
+            return unless match( shift(@input), $matcher );
         }
     }
 
@@ -116,7 +109,7 @@ sub satisfied_by {
             unless @expected == 0;
 
         # uncoverable branch true
-        return if ! $slurp->($matcher, @input);
+        return unless $slurp->( $matcher, @input );
     }
 
     return @input == 0 && @expected == 0;
